@@ -6,14 +6,21 @@ test_that(
     skip_on_cran()
 
     expect_s3_class(
-      finbif_collections(taxonomic_coverage == "Coleoptera"), "data.frame"
+      finbif_collections(taxonomic_coverage == "Coleoptera", cache = 1),
+      "data.frame"
     )
+
     expect_s3_class(
       finbif_collections(subcollections = FALSE, supercollections = TRUE),
       "data.frame"
     )
+
     expect_s3_class(
-      finbif_collections(select = NA, nmin = NA), "data.frame"
+      finbif_collections(select = NA, nmin = NA, cache = 1e-9), "data.frame"
+    )
+
+    expect_s3_class(
+      finbif_collections(select = NA, nmin = NA, cache = 1e-9), "data.frame"
     )
 
   }
