@@ -47,7 +47,7 @@ test_that(
 test_that(
   "default type is character", {
 
-    expect_type(cast_to_type(1, NULL), "character")
+    expect_type(cast_to_type(1, ""), "character")
 
   }
 )
@@ -59,15 +59,3 @@ test_that(
 
   }
 )
-
-test_that(
-  "deprecation warning works", {
-
-    Sys.setenv(DEPRECATION_WARNING = TRUE)
-
-    expect_warning(deprecation("msg"), "msg")
-
-    Sys.setenv(DEPRECATION_WARNING = FALSE)
-
-  }
-)
